@@ -44,31 +44,28 @@ def cli():
     start_console(locals={"walker": walker})
 
 
-# @main.command()
-# @click.argument("script_location", type=click.Path(exists=True, dir_okay=False))
-# def run_script(script_location):
-#     script_location = Path(script_location)
-#     parsed = parse(script_location.read_text())
-#
-#     walker = WizWalker()
-#
-#     asyncio.run(run_wizwalker_script(walker, parsed))
-
-
+# TODO: 2.0: remove --nowait, make start_instances_with_login not wait if there are no logins
 @main.command()
 @click.option(
     "--instances", default=1, show_default=True, help="Number of instances to start"
 )
 @click.argument("logins", nargs=-1)
-def start_wiz(instances, logins):
+@click.option(
+    "--nowait", is_flag=True, default=False, help="Don't wait for completion of startup process",
+)
+def start_wiz(instances, logins, nowait):
     """
     Start multiple wizard101 instances and optionally login to them
     """
-    if instances != len(logins) and instances != 1:
+    num_logins = len(logins)
+    if instances != num_logins and instances != 1:
         click.echo("Not enough or too many logins for the number of instances")
         exit(1)
 
-    asyncio.run(utils.start_instances_with_login(instances, logins))
+    if num_logins > instances:
+        instances = num_logins
+
+    asyncio.run(utils.start_instances_with_login(instances, logins, wait_for_ready=not nowait))
 
 
 @main.group()
