@@ -262,7 +262,7 @@ class DuelHook(SimpleHook):
         rb"\x44\x0F\xB6\xE0\x88\x44\x24\x60\xE8....\x44\x8D\x6B\x0F"
         rb"\x44\x8D\x73\x10\x4C\x8D.....\x83\xF8\x64\x7E\x0A\xE8....\xE9"
     )
-    exports = [("current_duel_addr", 8)]
+    exports = [("current_duel_addr", 8), ("current_duel_phase", 4)]
     instruction_length = 8
     noops = 3
 
@@ -271,10 +271,12 @@ class DuelHook(SimpleHook):
         bytecode = (
                 # if al == 1 rcx is ClientDuel
                 b"\x84\xc0"  # test al,al
-                b"\x74\x0F"  # je 8
+                b"\x74\x20"  # je 32 (to original code)
                 b"\x50"  # push rax
                 b"\x48\x89\xc8"  # mov rax,rcx
                 b"\x48\xA3" + packed_exports[0][1] +  # movabs [current_duel_addr],rax
+                b"\x48\x8B\x80\xC4\x00\x00\x00"  # mov rax,[rax+C4]
+                b"\x48\xA3" + packed_exports[1][1] +  # movabs [current_duel_phase],rax
                 b"\x58"  # pop rax
                 # original code
                 b"\x44\x0F\xB6\xE0"  # movzx r12d,al
@@ -284,6 +286,10 @@ class DuelHook(SimpleHook):
 
         return bytecode
 
+    async def posthook(self):
+        # init duel phase with 7 so in_combat returns False
+        await self.write_typed(self.current_duel_phase, 7, "unsigned int")
+
 
 class ClientHook(SimpleHook):
     pattern = (
@@ -613,6 +619,7 @@ class MouselessCursorMoveHook(User32GetClassInfoBaseHook):
         self.mouse_pos_addr = None
 
         self.toggle_bool_addrs = ()
+        self.set_cursor_pos = None
 
     async def hook(self):
         """
@@ -667,6 +674,12 @@ class MouselessCursorMoveHook(User32GetClassInfoBaseHook):
         await self.write_bytes(bool_one_address, b"\x01")
         await self.write_bytes(bool_two_address, b"\x01")
 
+        set_cursor_pos = await self.get_address_from_symbol("user32.dll", "SetCursorPos")
+        self.set_cursor_pos = (set_cursor_pos, await self.read_bytes(set_cursor_pos, 6))
+
+        # ret + 5 noops
+        await self.write_bytes(set_cursor_pos, b"\xC3" + (b"\x90" * 5))
+
     async def set_mouse_pos_addr(self):
         self.mouse_pos_addr = await self.allocate(8)
 
@@ -707,3 +720,7 @@ class MouselessCursorMoveHook(User32GetClassInfoBaseHook):
         await self.free_mouse_pos_addr()
         for bool_addr in self.toggle_bool_addrs:
             await self.write_bytes(bool_addr, b"\x00")
+
+        if self.set_cursor_pos:
+            set_cursor_pos, set_cursor_pos_bytes = self.set_cursor_pos
+            await self.write_bytes(set_cursor_pos, set_cursor_pos_bytes)
