@@ -1,4 +1,4 @@
-from typing import List
+from typing import List, Optional
 
 from wizwalker.memory.memory_object import PropertyClass, DynamicMemoryObject
 from .spell_effect import DynamicSpellEffect
@@ -14,8 +14,12 @@ class CombatResolver(PropertyClass):
     async def write_bool_global_effect(self, bool_global_effect: bool):
         await self.write_value_to_offset(112, bool_global_effect, "bool")
 
-    async def global_effect(self) -> DynamicSpellEffect:
+    async def global_effect(self) -> Optional[DynamicSpellEffect]:
         addr = await self.read_value_from_offset(120, "long long")
+
+        if addr == 0:
+            return None
+
         return DynamicSpellEffect(self.hook_handler, addr)
 
     async def battlefield_effects(self) -> List[DynamicSpellEffect]:
