@@ -11,7 +11,7 @@ class MouseHandler:
     Handles clicking/moving the mouse position
     """
 
-    def __init__(self, client: "wizwalker.client"):
+    def __init__(self, client: "wizwalker.Client"):
         self.client = client
         self.click_lock = None
 
@@ -19,7 +19,6 @@ class MouseHandler:
         """
         Activates the mouseless hook
         """
-        # this will error if already active for us
         await self.client.hook_handler.activate_mouseless_cursor_hook()
 
     async def deactivate_mouseless(self):
@@ -111,6 +110,7 @@ class MouseHandler:
         else:
             send_method = user32.SendMessageW
 
+        # so MouseHandler can be inited in sync funcs like other __init__s
         if self.click_lock is None:
             self.click_lock = asyncio.Lock()
 
